@@ -36,10 +36,10 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/include/python3.10',
     'py_inc_dir':         '/usr/include/python3.10',
     'py_lib_dir':         '/usr/lib/python3.10/config',
-    'py_version':         0x030a08,
+    'py_version':         0x030a0a,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/sip4/src=/usr/src/debug/sip4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/sip4/src=/usr/src/debug/sip4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now --no-dist-info',
     'sip_inc_dir':        '/usr/include/python3.10',
     'sip_module_dir':     '/usr/lib/python3.10/site-packages',
     'sip_root_dir':       '/usr/lib/python3.10/site-packages',
